@@ -53,8 +53,8 @@ class QLoss(object):
 
             # (batch_size, 1) * (1, num_atoms) = (batch_size, num_atoms)
             r_tau = tf.expand_dims(
-                rewards, -1) + gamma**n_step * tf.expand_dims(
-                    1.0 - done_mask, -1) * tf.expand_dims(z, 0)
+                rewards, -1) + gamma ** n_step * tf.expand_dims(
+                1.0 - done_mask, -1) * tf.expand_dims(z, 0)
             r_tau = tf.clip_by_value(r_tau, v_min, v_max)
             b = (r_tau - v_min) / ((v_max - v_min) / float(num_atoms - 1))
             lb = tf.floor(b)
@@ -91,11 +91,11 @@ class QLoss(object):
             q_tp1_best_masked = (1.0 - done_mask) * q_tp1_best
 
             # compute RHS of bellman equation
-            q_t_selected_target = rewards + gamma**n_step * q_tp1_best_masked
+            q_t_selected_target = rewards + gamma ** n_step * q_tp1_best_masked
 
             # compute the error (potentially clipped)
             self.td_error = (
-                q_t_selected - tf.stop_gradient(q_t_selected_target))
+                    q_t_selected - tf.stop_gradient(q_t_selected_target))
             self.loss = tf.reduce_mean(
                 tf.cast(importance_weights, tf.float32) * huber_loss(
                     self.td_error))
@@ -185,7 +185,6 @@ def postprocess_trajectory(policy,
 
 
 def build_q_model(policy, obs_space, action_space, config):
-
     if not isinstance(action_space, Discrete):
         raise UnsupportedSpaceException(
             "Action space {} is not supported for DQN.".format(action_space))
@@ -236,7 +235,6 @@ def build_q_model(policy, obs_space, action_space, config):
 
 def build_q_networks(policy, q_model, input_dict, obs_space, action_space,
                      config):
-
     # Action Q network
     q_values, q_logits, q_dist = _compute_q_values(
         policy, q_model, input_dict[SampleBatch.CUR_OBS], obs_space,
@@ -324,10 +322,10 @@ def build_q_losses(policy, model, _, train_batch):
     # compute estimate of best possible value starting from state at t + 1
     if config["double_q"]:
         q_tp1_using_online_net, q_logits_tp1_using_online_net, \
-            q_dist_tp1_using_online_net = _compute_q_values(
-                policy, policy.q_model,
-                train_batch[SampleBatch.NEXT_OBS],
-                policy.observation_space, policy.action_space)
+        q_dist_tp1_using_online_net = _compute_q_values(
+            policy, policy.q_model,
+            train_batch[SampleBatch.NEXT_OBS],
+            policy.observation_space, policy.action_space)
         q_tp1_best_using_online_net = tf.argmax(q_tp1_using_online_net, 1)
         q_tp1_best_one_hot_selection = tf.one_hot(q_tp1_best_using_online_net,
                                                   policy.action_space.n)
@@ -390,7 +388,8 @@ def setup_late_mixins(policy, obs_space, action_space, config):
 
 
 def _compute_q_values(policy, model, obs, obs_space, action_space):
-    action_mask = tf.cast(obs[:, 0:300], tf.float32)
+    # action_mask = tf.cast(obs[:, 0:300], tf.float32)
+    action_mask = tf.cast(obs[:, 0:100], tf.float32)
     config = policy.config
     model_out, state = model({
         "obs": obs,
@@ -410,8 +409,8 @@ def _compute_q_values(policy, model, obs, obs_space, action_space):
             support_logits_per_action_mean = tf.reduce_mean(
                 support_logits_per_action, 1)
             support_logits_per_action_centered = (
-                support_logits_per_action - tf.expand_dims(
-                    support_logits_per_action_mean, 1))
+                    support_logits_per_action - tf.expand_dims(
+                support_logits_per_action_mean, 1))
             support_logits_per_action = tf.expand_dims(
                 state_score, 1) + support_logits_per_action_centered
             support_prob_per_action = tf.nn.softmax(
@@ -422,17 +421,20 @@ def _compute_q_values(policy, model, obs, obs_space, action_space):
             dist = support_prob_per_action
         else:
             # action_scores_mean = reduce_mean_ignore_inf(action_scores, 1)
-            # action_scores_centered = action_scores - tf.expand_dims(
-            #     action_scores_mean, 1)
+            # action_scores_centered = action_scores - tf.expand_dims(action_scores_mean, 1)
             # value = state_score + action_scores_centered
+
             mask = tf.cast(tf.not_equal(action_scores, tf.float32.min), tf.float32)
             mask = mask * action_mask
             x_zeroed = action_scores * mask
             action_scores_mean = (tf.reduce_sum(x_zeroed, 1) / tf.reduce_sum(mask, 1))
-
             action_scores_centered = action_scores - tf.expand_dims(action_scores_mean, 1)
-            inf_mask = tf.maximum(tf.log(mask), tf.float32.min)
-            value = state_score + action_scores_centered + inf_mask
+            # inf_mask = tf.maximum(tf.log(mask), tf.float32.min)
+            # value = state_score + action_scores_centered + inf_mask
+
+            value = state_score + action_scores_centered
+            paddings = tf.ones_like(value) * (-2 ** 32 + 1)
+            logits = tf.where(tf.equal(mask, 1.0), value, paddings)
     else:
         value = action_scores
 
@@ -461,7 +463,7 @@ def _adjust_nstep(n_step, gamma, obs, actions, rewards, new_obs, dones):
             if i + j < traj_length:
                 new_obs[i] = new_obs[i + j]
                 dones[i] = dones[i + j]
-                rewards[i] += gamma**j * rewards[i + j]
+                rewards[i] += gamma ** j * rewards[i + j]
 
 
 def _postprocess_dqn(policy, batch):
@@ -482,7 +484,7 @@ def _postprocess_dqn(policy, batch):
             batch[SampleBatch.REWARDS], batch[SampleBatch.NEXT_OBS],
             batch[SampleBatch.DONES], batch[PRIO_WEIGHTS])
         new_priorities = (
-            np.abs(td_errors) + policy.config["prioritized_replay_eps"])
+                np.abs(td_errors) + policy.config["prioritized_replay_eps"])
         batch.data[PRIO_WEIGHTS] = new_priorities
 
     return batch
