@@ -22,7 +22,7 @@ def exec_hive(sqlfiles, ds, conn_type='impala'):
         for i in range(len(USER_QUERY_SQLs)):
             user_sql = USER_QUERY_SQLs[i].replace('2019-04-01', ds)
             print('exec_sql: ', user_sql)
-            if conn_type=='impala' or 'invalidate' in user_sql.lower():
+            if (conn_type=='impala' and '--hive' not in user_sql.lower()) or 'invalidate' in user_sql.lower():
                 df = impala_handler.exec_sql_dml(sql=user_sql)
             else:
                 df = hive_handler.exec_sql_dml(sql=user_sql)
